@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2011 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "components.h"
 #include "puzzle.h"
@@ -34,7 +22,7 @@ Palapeli::PuzzleComponent* Palapeli::RetailStorageComponent::cast(Type type) con
 	//all casting via CreationContextComponent
 	if (type != CreationContext)
 	{
-		return puzzle()->get(CreationContext).result()->cast(type);
+		return puzzle()->get(CreationContext)->cast(type);
 	}
 	//create creation context
 	Palapeli::PuzzleCreationContext creationContext;
